# CLIbrary contributing guidelines

Guidelines inspired by [Ruby on Rails](https://github.com/rails/rails/blob/main/CONTRIBUTING.md)'.

## Feedback, suggestions and bug reports

Feedbacks, suggestions and bug reports should be issued via:

* GitHub's Issue Tracker.
* GitHub's discussions.

### Bug reports

* Do not open up a GitHub issue if the bug is a security vulnerability, and instead to refer to the [security policy](https://github.com/diantonioandrea/CLIbrary/security/policy).

* Ensure the bug was not already reported by searching on GitHub under [Issues](https://github.com/diantonioandrea/CLIbrary/issues).

* If you're unable to find an open issue addressing the problem, [open a new one](https://github.com/diantonioandrea/CLIbrary/issues/new). Be sure to include a title and clear description, as much relevant information as possible, and a code sample or an executable test case demonstrating the expected behavior that is not occurring.

* If possible, use the relevant bug report templates to create the issue.

## Contacts

* <a href="mailto:mail@diantonioandrea.com?subject=CLIbrary contribution">Andrea Di Antonio</a>.